@@ -76,22 +76,9 @@ class Install(MethodsInterface):
         else:
             self.clVars = datavars
 
-    def canInstallGrub2(self, target):
-        """Check that system has grub2 in current and installed system"""
-        if self.clVars.Get('os_grub2_path'):
-            return bool([x for x in listDirectory('/var/db/pkg/sys-boot') 
-                if (x.startswith('grub-1.99') or x.startswith('grub-2'))])
-        return False
-
     def prepareBoot(self, target_distr):
-        """Prepare system for boot"""
-        if self.clVars.Get('os_install_root_type') == "flash":
-            self.installSyslinuxBootloader(target_distr)
-        else:
-            if self.canInstallGrub2(target_distr):
-                self.installGrub2Bootloader(target_distr)
-            else:
-                self.installLegacyGrubBootloader(target_distr)
+        """Prepare flash for boot"""
+        self.installSyslinuxBootloader(target_distr)
         return True
 
     def setActivePartition(self, partition):
@@ -533,6 +520,7 @@ class Install(MethodsInterface):
             os.rename(mask_file, mask_file + "2")
             os.mkdir(mask_file, mode=0o755)
             os.rename(mask_file + "2", path.join(mask_file, "default"))
+
         current_nvidia_mask = readFile(nvidia_mask_file).strip()
         new_nvidia_mask = self.clVars.Get('os_nvidia_mask')
         if new_nvidia_mask == current_nvidia_mask:
@@ -781,8 +769,13 @@ class Install(MethodsInterface):
             install_admin.save()
         return True
 
-
     def init_themes(self):
         self.clVars.Get('cl_splash_image_hash')
         self.clVars.Get('cl_grub_image_hash')
         return True
+
+    def check_success_configure(self):
+        try:
+            return self.clVars.GetBool("cl_success_configure")
+        except:
+            return True
