@@ -173,8 +173,8 @@ class Wsdl(WsdlBase):
                 lambda group: group(_("Flash install"),
                                     normal=('cl_image_filename',
                                             'os_install_disk_single',
-                                            'os_install_format_single_set',
-                                            'cl_target_fs'),
+                                            'cl_target_fs',
+                                            'os_install_format_single_set'),
                                     next_label=_("Run"))],
             'brief': {'next': __("Run"),
                       'name': __("Start installing")}},
